package com.ibm.sysmgt.raidmgr.debug;
      
import com.ibm.sysmgt.raidmgr.mgtGUI.Launch;
import com.ibm.sysmgt.raidmgr.wizard.hotswap.HotSwapConstants;
import com.ibm.sysmgt.storage.api.HotPCISlots;
import com.ibm.sysmgt.storage.api.StorRet;
import com.ibm.sysmgt.raidmgr.util.Constants;
import com.ibm.sysmgt.raidmgr.images.JCRMImageIcon;

import javax.swing.*;
import javax.swing.border.BevelBorder;
import java.awt.*;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

public class HotSwapDebugger extends JFrame
{
   private JButton statusButton;
   private JButton powerOnButton;
   private JButton powerOffButton;
   private JButton scrollClearButton;
   private JButton hotSlotsButton;
   private JTextArea textArea;
   private JTextField adapterNum;
   private JTextField slotNum;

   public HotSwapDebugger(String title)
   {
      super(title);
      buildGUI();

      ActionListener onAL = new ActionListener() 
      {
         public void actionPerformed(ActionEvent e)
         {            
            int adapter = 0;
            int slot = 0;
            try {
               adapter = Integer.parseInt(adapterNum.getText().trim());
               slot = Integer.parseInt(slotNum.getText().trim());
            } catch (NumberFormatException ex)
            {
               textArea.append(ex + "\n");
            }

            StorRet ret = new StorRet(-1);
            try {
               ret = Launch.getDP().setSlotPowerState(adapter, slot, true);
            }            
            catch (Exception ex)
            {
               textArea.append(ex + "\n");
               return;
            }

            textArea.append("Set slot " + slot + " power state on returned (ReturnCode = " + ret.iReturnCode + "  ReturnValue = " + ret.iSignedReturnValue + ").\n");
         }
      };

      ActionListener offAL = new ActionListener() 
      {
         public void actionPerformed(ActionEvent e)
         {            
            int adapter = 0;
            int slot = 0;
            try {
               adapter = Integer.parseInt(adapterNum.getText().trim());
               slot = Integer.parseInt(slotNum.getText().trim());
            } catch (NumberFormatException ex)
            {
               textArea.append(ex + "\n");
            }

            StorRet ret = new StorRet(-1);
            try {
               ret = Launch.getDP().setSlotPowerState(adapter, slot, false);
            }
            catch (Exception ex)
            {
               textArea.append(ex + "\n");
               return;
            }

            textArea.append("Set slot " + slot + " power state off returned (ReturnCode = " + ret.iReturnCode + "  ReturnValue = " + ret.iSignedReturnValue + ").\n");
         }
      };

      ActionListener statusAL = new ActionListener() 
      {
         public void actionPerformed(ActionEvent e)
         {            
            int adapter = 0;
            int slot = 0;
            try {
               adapter = Integer.parseInt(adapterNum.getText().trim());
               slot = Integer.parseInt(slotNum.getText().trim());
            } catch (NumberFormatException ex)
            {
               textArea.append(ex + "\n");
            }
            
            StorRet ret = new StorRet(-1);
            try {
               ret = Launch.getDP().getSlotPowerState(adapter, slot);
            }
            catch (Exception ex)
            {
               textArea.append(ex + "\n");
               return;
            }

            String onOrOff = new String("Unknown");
            if (ret.iSignedReturnValue == HotSwapConstants.SLOT_POWER_ON)
               onOrOff = "ON";
            else if (ret.iSignedReturnValue == HotSwapConstants.SLOT_POWER_OFF)
               onOrOff = "OFF";
                                             
            textArea.append("ret.iSignedReturnValue = " + ret.iSignedReturnValue + "\n");
            textArea.append("Slot " + slot + " is powered " + onOrOff + " (ReturnCode =" + ret.iReturnCode + ").\n");
         }
      };

      ActionListener slotsAL = new ActionListener() 
      {
         public void actionPerformed(ActionEvent e)
         {            
            HotPCISlots slots = new HotPCISlots();
            try {
               slots = Launch.getDP().findHotPCISlots();
            }            
            catch (Exception ex)
            {
               textArea.append(ex + "\n");
               return;
            }
            
            int adapter = 0;
            int slot = 0;
            try {
               adapter = Integer.parseInt(adapterNum.getText().trim());
               slot = Integer.parseInt(slotNum.getText().trim());
            } catch (NumberFormatException ex)
            {
               textArea.append(ex + "\n");
            }

            if (slots == null)
            {
               textArea.append("NOT a Hot PCI Slot.\n");
               return;
            }

            if (slots.isHotSlot(slot) == true)
               textArea.append("Slot " + slot + " is hot.\n");
            else
               textArea.append("NOT a Hot PCI Slot.\n");
         }
      };

      powerOnButton.addActionListener(onAL);
      powerOffButton.addActionListener(offAL);
      statusButton.addActionListener(statusAL);
      hotSlotsButton.addActionListener(slotsAL);
   }

   private void buildGUI()
   {      
      int frameWidth = 400;
      int frameHeight = 200;

      JPanel fieldPanel = new JPanel();
      JPanel buttonPanel = new JPanel();
      JPanel outputPanel = new JPanel();
      fieldPanel.setLayout(new GridLayout(0, 4, 5, 5));
      buttonPanel.setLayout(new GridLayout(0,3, 5, 5));      
      outputPanel.setLayout(new BorderLayout());

      JLabel adapterNumLabel = new JLabel("Adapter Number");
      JLabel slotNumLabel = new JLabel("Slot Number");
      adapterNum = new JTextField("0");
      slotNum = new JTextField("0");

      powerOnButton = new JButton("Power On");      
      powerOffButton = new JButton("Power Off");
      statusButton = new JButton("Get Status");
      scrollClearButton = new JButton("C");
      hotSlotsButton = new JButton("Hot PCI Slot?");

      fieldPanel.add(adapterNumLabel);
      fieldPanel.add(adapterNum);
      fieldPanel.add(slotNumLabel);
      fieldPanel.add(slotNum);

      buttonPanel.add(powerOnButton);
      buttonPanel.add(powerOffButton);
      buttonPanel.add(statusButton);
      buttonPanel.add(hotSlotsButton);

      textArea = new JTextArea(6, 30);
      textArea.setLineWrap(true);
      textArea.setWrapStyleWord(true);
            
      JScrollPane s = new JScrollPane(textArea);
      s.setPreferredSize(new Dimension(frameWidth -20, 125));

      outputPanel.add(s, BorderLayout.CENTER);            

      Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();      
      this.setLocation(screenSize.width/2 - frameWidth/2, screenSize.height/2 - frameHeight/2);

      this.setSize(new Dimension(frameWidth, frameHeight));
      this.getContentPane().setLayout(new BorderLayout(10, 10));            
      this.getContentPane().add(fieldPanel, BorderLayout.NORTH);
      this.getContentPane().add(buttonPanel, BorderLayout.SOUTH);
      this.getContentPane().add(outputPanel, BorderLayout.CENTER);      
      
      ImageIcon icon = new JCRMImageIcon( "bug6.gif" ); 
      this.setIconImage( icon.getImage() );
   }

   public static void main(String argv[])
   {
      HotSwapDebugger d = new HotSwapDebugger("Hot-Swap Debugger");
      d.addWindowListener(new WindowAdapter() {
                                 public void windowClosing(WindowEvent e)
                                 {
                                    System.exit(0);
                                 }
                              });
      d.show();
   }
}

