package com.ibm.sysmgt.raidmgr.debug;

import javax.swing.*;
import javax.swing.table.*;
import java.util.*;
import com.ibm.sysmgt.raidmgr.util.*;

class ThreadDebuggerTableModel extends AbstractTableModel
{
   Vector threads;

   String headers[] = { "Thread", "Thread Group", "Priority", "isAlive", "isInterrupted" };
   Class columnClasses[] = { String.class, String.class, Integer.class, String.class, String.class };

   ThreadDebuggerTableModel()
   {
      threads = new Vector();
      refresh();
   }

   public void refresh()
   {
      threads.removeAllElements();

      // Get the top level thread group
      ThreadGroup group = Thread.currentThread().getThreadGroup();
      while (group.getParent() != null)
         group = group.getParent();

      // Get all the threads in the current JVM
      Thread[] threadArray = new Thread[group.activeCount() * 2];
      group.enumerate(threadArray, true /*recurse*/);

      // Move non-null references into the vector
      for (int i = 0; (i < threadArray.length) && (threadArray[i] != null); i++)
         threads.addElement(threadArray[i]);

      // Update the table
      fireTableDataChanged();
   }

   public Vector getThreads()
   {
      return (Vector) threads.clone();
   }

   public int getRowCount()
   {
      return (threads == null) ? 0 : threads.size();
   }

   public int getColumnCount()
   {
      return headers.length;
   }

   public String getColumnName(int col)
   {
      return headers[col];
   }

   public Class getColumnClass(int col)
   {
      return columnClasses[col];
   }

   public boolean isCellEditable(int row, int col)
   {
      return (getColumnClass(col).equals(String.class)) ? false : true;
   }

   public Object getValueAt(int row, int col)
   {
      Thread thread = (Thread) threads.elementAt(row);
      if (thread == null)
         return "null";

      String name = thread.getName();
      ThreadGroup group = thread.getThreadGroup();
      String groupName = (group == null) ? "" : group.getName();

      switch (col)
      {
         case 0: return name;
         case 1: return groupName;
         case 2: return new Integer(thread.getPriority());
         case 3: return thread.isAlive() ? "Yes" : "No";
         case 4: return thread.isInterrupted() ? "Yes" : "No";
         default: return null;
      }
   }
}
